@@ -26,7 +26,11 @@ EicielWindow::EicielWindow(EicielMainController* cont)
 	_cb_acl_default(_("Default")),
 	_tb_modify_default_acl(_("Default ACL")),
 	_cb_show_system_participants(_("Also show system participants")),
+#ifdef USING_GNOME2
 	_middle_button_group(Gtk::BUTTONBOX_DEFAULT_STYLE, 2),
+#else // in gtkmm-3 BUTTONBOX_DEFAULT_STYLE was removed from public headers, and is only set by constructor with no arguments
+	_middle_button_group(),
+#endif
 	_b_add_acl(Gtk::Stock::ADD), 
 	_b_remove_acl(Gtk::Stock::REMOVE),
 	_top_frame(_("Access Control List")),
@@ -55,6 +59,10 @@ EicielWindow::EicielWindow(EicielMainController* cont)
 	_bottom_area.set_border_width(4);
 	_bottom_area.set_spacing(4);
 
+#ifndef USING_GNOME2
+	_middle_button_group.set_spacing(2);
+#endif
+
 	// Open icons
 	_user_icon = Gdk::Pixbuf::create_from_file(PKGDATADIR "/img/user.png");
 	_user_icon_acl = Gdk::Pixbuf::create_from_file(PKGDATADIR "/img/user-acl.png");
@@ -192,7 +200,11 @@ EicielWindow::EicielWindow(EicielMainController* cont)
 	_listview_participants.set_size_request(-1, 150);
 
 	// Drag & Drop stuff
+#ifdef USING_GNOME2
 	std::list<Gtk::TargetEntry> list_targets;
+#else
+	std::vector<Gtk::TargetEntry> list_targets;
+#endif
 	list_targets.push_back( Gtk::TargetEntry("participant_acl") );
 
 	// _listview_participants es the source of the drag
@@ -259,7 +271,11 @@ EicielWindow::EicielWindow(EicielMainController* cont)
 
 	// Column edition event
 	Gtk::TreeViewColumn* col = _listview_acl.get_column(2);
+#ifdef USING_GNOME2
 	Gtk::CellRenderer* render = col->get_first_cell_renderer(); // Only one
+#else
+	Gtk::CellRenderer* render = col->get_first_cell(); // Only one
+#endif
 	CellRendererACL* toggle_render = dynamic_cast<CellRendererACL*>(render);
 
 	toggle_render->signal_toggled().connect(
@@ -267,7 +283,11 @@ EicielWindow::EicielWindow(EicielMainController* cont)
 			);
 
 	col = _listview_acl.get_column(3);
+#ifdef USING_GNOME2
 	render = col->get_first_cell_renderer();
+#else
+	render = col->get_first_cell();
+#endif
 	toggle_render = dynamic_cast<CellRendererACL*>(render);
 
 	toggle_render->signal_toggled().connect(
@@ -275,7 +295,11 @@ EicielWindow::EicielWindow(EicielMainController* cont)
 			);
 
 	col = _listview_acl.get_column(4);
+#ifdef USING_GNOME2
 	render = col->get_first_cell_renderer();
+#else
+	render = col->get_first_cell();
+#endif
 	toggle_render = dynamic_cast<CellRendererACL*>(render);
 
 	toggle_render->signal_toggled().connect(
